@@ -9,7 +9,6 @@ import json
 from jaaql.utilities.utils import get_jaaql_root
 from jaaql.constants import VERSION
 
-
 ERR__empty_example_list = "Empty examples list for argument '%s'"
 ERR__null_example = "No examples found for argument '%s'"
 ERR__example_type = "Found type '%s' for example #%d, argument '%s'. Doesn't match type '%s'"
@@ -24,6 +23,8 @@ ERR__documentation_variable_expected = "Expected '%s' variable in documentation
 ERR__empty_path = "Empty path for documentation. Variable unused or documentation occuring before controller import"
 ERR__nested_not_allowed = "Nested objects are not allowed in method arguments. Please place in the body"
 ERR__list_not_allowed = "Lists now allowed in method arguments. Please place in the body"
+ERR__delete_not_allowed_body = "HTTP method delete isn't allowed a body. Please use the arguments parameter instead"
+ERR__get_not_allowed_body = "HTTP method get isn't allowed a body. Please use the arguments parameter instead"
 
 TYPE__example = Union[List[Any], Any]
 
@@ -173,15 +174,19 @@ class SwaggerArgumentResponse:
 
     def __init__(self, name: str, description: str,
                  arg_type: Union[type, List['SwaggerArgumentResponse'], 'SwaggerList', SwaggerSimpleList],
-                 example: Optional[TYPE__example] = None, required: bool = False, condition: str = None,
-                 local_only: bool = False):
+                 example: Optional[TYPE__example] = None, required: bool = True, condition: str = None,
+                 local_only: bool = False, strip: bool = True, lower: bool = False):
         self.name = name
         self.description = description
+        if arg_type == bool and example is None:
+            example = [True, False]
         self.example = force_list(example)
         self.required = required
         self.arg_type = arg_type
         self.condition = condition
         self.local_only = local_only
+        self.strip = strip
+        self.lower = lower
 
         if not required and condition is None and name != DOCUMENTATION__allow_all:
             raise SwaggerException(ERR__condition_needed % name)
@@ -192,8 +197,7 @@ class SwaggerArgumentResponse:
         if arg_type_sub_list:
             arg_type_sub_list = all([isinstance(x, SwaggerArgumentResponse) for x in arg_type])
 
-        if not arg_type_sub_list and not isinstance_union(arg_type,
-                                                          TYPE__swagger_list_like) and name != DOCUMENTATION__allow_all:
+        if not arg_type_sub_list and not isinstance_union(arg_type, TYPE__swagger_list_like) and not self.is_arg_all():
             self._validate_example(name, arg_type, self.example)
 
     @staticmethod
@@ -210,6 +214,12 @@ class SwaggerArgumentResponse:
         if len(example) != len(set(example)):
             raise SwaggerException(ERR__duplicated_example % name)
 
+    def is_arg_all(self):
+        if isinstance(self.arg_type, SwaggerArgumentResponse):
+            if self.arg_type.name == DOCUMENTATION__allow_all:
+                return True
+        return self.name == DOCUMENTATION__allow_all
+
 
 class SwaggerList:
 
@@ -219,9 +229,8 @@ class SwaggerList:
 
 TYPE__swagger_list_like = Union[SwaggerSimpleList, SwaggerList]
 
-
 ARG_RESP__allow_all = SwaggerArgumentResponse(DOCUMENTATION__allow_all, DOCUMENTATION__allow_all, str)
-
+BODY__file = "JAAQL_IS_FILE"
 
 TYPE__argument_response = Optional[Union[List[SwaggerArgumentResponse], SwaggerArgumentResponse, SwaggerList,
                                          SwaggerSimpleList]]
@@ -255,7 +264,7 @@ def validate_argument_responses(arg_responses: TYPE__argument_response):
 
 class SwaggerFlatResponse:
 
-    def __init__(self, description: str = "HTTP OK", code: HTTPStatus = HTTPStatus.OK, resp_type: type = str,
+    def __init__(self, description: str = "HTTP OK", code: Union[HTTPStatus, int] = HTTPStatus.OK, resp_type: type = str,
                  body: str = RESPONSE__OK):
         self.code = code
         self.description = description
@@ -271,9 +280,11 @@ MOCK__description = ""
 
 class SwaggerResponse:
 
-    def __init__(self, description: str, code: HTTPStatus = HTTPStatus.OK, response: TYPE__argument_response = None):
+    def __init__(self, description: str, code: HTTPStatus = HTTPStatus.OK, response: TYPE__argument_response = None,
+                 error_on_unexpected_field: bool = False):
         self.code = code
         self.description = description
+        self.error_on_unexpected_field = error_on_unexpected_field
 
         validate_argument_responses(response)
 
@@ -285,7 +296,6 @@ RES__allow_all = SwaggerResponse(
     response=ARG_RESP__allow_all
 )
 
-
 TYPE__response = Union[SwaggerFlatResponse, SwaggerResponse]
 TYPE__responses = Optional[Union[TYPE__response, List[TYPE__response]]]
 
@@ -314,6 +324,12 @@ class SwaggerMethod:
         if not found_500:
             self.exceptions.append(SwaggerResponseException())
 
+        if self.method == REST__DELETE and len(self.body) != 0:
+            raise Exception(ERR__delete_not_allowed_body)
+
+        if self.method == REST__GET and len(self.body) != 0:
+            raise Exception(ERR__get_not_allowed_body)
+
     @staticmethod
     def _validate_exceptions(exceptions: TYPE__exceptions):
         if exceptions is not None and isinstance(exceptions, list):
@@ -386,7 +402,10 @@ def _build_yaml(yaml: str, indent: int, attr: str, value: Union[str, List[str]]
 
 
 def _http_status_to_integer(code: HTTPStatus) -> int:
-    return code.value
+    if isinstance(code, int):
+        return code
+    else:
+        return code.value
 
 
 def _insert_yaml_line(yaml: str) -> str:
@@ -398,11 +417,13 @@ def _to_openapi_type(python_type: type) -> str:
         return OPEN_API__object
     elif isinstance(python_type, SwaggerList):
         return OPEN_API__array
+    elif isinstance(python_type, SwaggerArgumentResponse):
+        return OPEN_API__object
     else:
         return OPEN_API__typemap[python_type]  # Lint issue PYC
 
 
-def _generate_examples(yaml: str, depth: int, response: TYPE__listed_argument_response) -> str:
+def _generate_examples(yaml: str, depth: int, response: TYPE__listed_argument_response, is_prod: bool) -> str:
     if isinstance(response, SwaggerList):
         yaml = yaml + _gen_yaml_indent(depth) + YAML__list_separator + YAML__new_line
         response = response.responses
@@ -413,23 +434,28 @@ def _generate_examples(yaml: str, depth: int, response: TYPE__listed_argument_re
 
     for response_property in response:
         if isinstance(response_property, SwaggerList):
-            yaml = _generate_examples(yaml, depth + 1, response_property)
+            yaml = _generate_examples(yaml, depth + 1, response_property, is_prod)
         else:
             is_complex = isinstance(response_property.arg_type, List)
 
+            if isinstance(response_property, SwaggerArgumentResponse) and response_property.local_only and is_prod:
+                continue
+
             if is_complex or isinstance(response_property.arg_type, SwaggerList):
                 yaml = _build_yaml(yaml, depth, response_property.name)
-                yaml = _generate_examples(yaml, depth + 1, response_property.arg_type)
+                yaml = _generate_examples(yaml, depth + 1, response_property.arg_type, is_prod)
             elif len(response_property.example) != 0:
                 raw_example = response_property.example[0]
                 if response_property.arg_type == str:
-                    raw_example = YAML__double_quote + raw_example + YAML__double_quote
+                    raw_example = YAML__double_quote + str(raw_example) + YAML__double_quote
                 yaml = _build_yaml(yaml, depth, response_property.name, raw_example)
+            elif response_property.arg_type == ARG_RESP__allow_all:
+                yaml = _build_yaml(yaml, depth, response_property.name, "{}")
 
     return yaml
 
 
-def _generate_properties(yaml: str, depth: int, response: TYPE__listed_argument_response) -> str:
+def _generate_properties(yaml: str, depth: int, response: TYPE__listed_argument_response, is_prod: bool) -> str:
     if isinstance(response, SwaggerList):
         yaml = _build_yaml(yaml, depth, OPEN_API__items)
         response = response.responses
@@ -439,19 +465,22 @@ def _generate_properties(yaml: str, depth: int, response: TYPE__listed_argument_
         yaml = _build_yaml(yaml, depth + 1, OPEN_API__type, _to_openapi_type(response.arg_type))
         return yaml
 
-    required = YAML__array_separator.join([YAML__double_quote + response_property.name + YAML__double_quote
-                                          for response_property in response if not isinstance(response_property,
-                                                                                              SwaggerList)
-                                          and response_property.required])
+    required_props = [YAML__double_quote + response_property.name + YAML__double_quote
+                      for response_property in response
+                      if not isinstance(response_property, SwaggerList) and response_property.required]
+    required = YAML__array_separator.join(required_props)
 
     if len(response) == 0 or not isinstance(response[0], SwaggerList):
-        yaml = _build_yaml(yaml, depth, OPEN_API__required, YAML__array_open + required + YAML__array_close)
+        if len(required_props) != 0:
+            yaml = _build_yaml(yaml, depth, OPEN_API__required, YAML__array_open + required + YAML__array_close)
         yaml = _build_yaml(yaml, depth, OPEN_API__properties)
 
     for response_property in response:
         if isinstance(response_property, SwaggerList):
-            yaml = _generate_properties(yaml, depth, response_property)
+            yaml = _generate_properties(yaml, depth, response_property, is_prod)
         else:
+            if isinstance(response_property, SwaggerArgumentResponse) and response_property.local_only and is_prod:
+                continue
             yaml = _build_yaml(yaml, depth + 1, response_property.name)
             yaml = _build_yaml(yaml, depth + 2, OPEN_API__description, response_property.description)
 
@@ -461,7 +490,7 @@ def _generate_properties(yaml: str, depth: int, response: TYPE__listed_argument_
             yaml = _build_yaml(yaml, depth + 2, OPEN_API__type, _to_openapi_type(response_property.arg_type))
 
             if is_complex:
-                yaml = _generate_properties(yaml, depth + 2, response_property.arg_type)
+                yaml = _generate_properties(yaml, depth + 2, response_property.arg_type, is_prod)
 
     return yaml
 
@@ -523,7 +552,7 @@ def _produce_path(doc: SwaggerDocumentation, yaml: str, is_prod: bool) -> str:
             if isinstance(method.body, SwaggerList):
                 yaml = _build_yaml(yaml, 8, OPEN_API__type, OPEN_API__array)
                 yaml = _build_yaml(yaml, 8, OPEN_API__example)
-                yaml = _generate_examples(yaml, 9, method.body)
+                yaml = _generate_examples(yaml, 9, method.body, is_prod)
                 yaml = _build_yaml(yaml, 8, OPEN_API__items)
                 yaml = _build_yaml(yaml, 9, OPEN_API__type, OPEN_API__object)
                 use_body = method.body.responses
@@ -531,8 +560,8 @@ def _produce_path(doc: SwaggerDocumentation, yaml: str, is_prod: bool) -> str:
             else:
                 yaml = _build_yaml(yaml, 8, OPEN_API__type, OPEN_API__object)
                 yaml = _build_yaml(yaml, 8, OPEN_API__example)
-                yaml = _generate_examples(yaml, 9, method.body)
-            yaml = _generate_properties(yaml, use_depth, use_body)
+                yaml = _generate_examples(yaml, 9, method.body, is_prod)
+            yaml = _generate_properties(yaml, use_depth, use_body, is_prod)
         yaml = _build_yaml(yaml, 3, OPEN_API__description, method.description)
         yaml = _build_yaml(yaml, 3, OPEN_API__responses)
 
@@ -553,7 +582,7 @@ def _produce_path(doc: SwaggerDocumentation, yaml: str, is_prod: bool) -> str:
                 if isinstance(response.responses, SwaggerList):
                     yaml = _build_yaml(yaml, 8, OPEN_API__type, OPEN_API__array)
                     yaml = _build_yaml(yaml, 8, OPEN_API__example)
-                    yaml = _generate_examples(yaml, 9, response.responses)
+                    yaml = _generate_examples(yaml, 9, response.responses, is_prod)
                     yaml = _build_yaml(yaml, 8, OPEN_API__items)
                     if isinstance(response.responses.responses[0], SwaggerList):
                         yaml = _build_yaml(yaml, 9, OPEN_API__type, OPEN_API__array)
@@ -563,12 +592,12 @@ def _produce_path(doc: SwaggerDocumentation, yaml: str, is_prod: bool) -> str:
                     use_response = response.responses.responses
                 elif isinstance(response.responses, SwaggerSimpleList):
                     yaml = _build_yaml(yaml, 8, OPEN_API__type, OPEN_API__array)
-                    yaml = _generate_examples(yaml, 8, response.responses)
+                    yaml = _generate_examples(yaml, 8, response.responses, is_prod)
                 else:
                     yaml = _build_yaml(yaml, 8, OPEN_API__type, OPEN_API__object)
                     yaml = _build_yaml(yaml, 8, OPEN_API__example)
-                    yaml = _generate_examples(yaml, 9, response.responses)
-                yaml = _generate_properties(yaml, use_depth, use_response)
+                    yaml = _generate_examples(yaml, 9, response.responses, is_prod)
+                yaml = _generate_properties(yaml, use_depth, use_response, is_prod)
             else:
                 yaml = _build_yaml(yaml, 8, OPEN_API__example, str(response.body))
 
